sip: Python extension module generator for C and C++ libraries
==============================================================

Description
-----------

Python extension module generator for C and C++ libraries


Upstream contact
----------------

-  https://www.riverbankcomputing.com/software/sip/
-  https://pypi.python.org/pypi/SIP

License
-------

SIP is released under the GPL v2, GPL v3 licenses, and under a
license
similar to the BSD license.

SIP is copyright (c) Riverbank Computing Limited. Its homepage is
https://www.riverbankcomputing.com/software/sip/.
